=========
sentinel2
=========


.. image:: https://img.shields.io/pypi/v/sentinel2.svg
        :target: https://pypi.python.org/pypi/sentinel2

.. image:: https://img.shields.io/travis/csaybar/sentinel2.svg
        :target: https://travis-ci.com/csaybar/sentinel2

.. image:: https://readthedocs.org/projects/sentinel2/badge/?version=latest
        :target: https://sentinel2.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A Python package for processing Sentinel-2 Level-1C product


* Free software: GNU General Public License v3
* Documentation: https://sentinel2.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
